@@ -22,11 +22,11 @@ Catalyst::Plugin::SmartURI - Configurable URIs for Catalyst
 
 =head1 VERSION
 
-Version 0.033
+Version 0.034
 
 =cut
 
-our $VERSION = '0.033';
+our $VERSION = '0.034';
 
 =head1 SYNOPSIS
 
@@ -140,22 +140,6 @@ duration of the request.
 
 =back
 
-=head1 USING WITH Catalyst::Controller::REST
-
-In MyApp.pm do something like this:
-
-    package MyApp;
-
-    use Catalyst::Runtime '5.70';
-    use parent 'Catalyst';
-
-    use Catalyst::Action::REST ();
-
-    __PACKAGE__->setup(qw/... your list of plugins including ... SmartURI .../);
-
-Because L<Catalyst::Action::REST> sets request_class at load time, SmartURI
-needs to see it at setup time to know which request class to extend.
-
 =head1 EXTENDING
 
 $c->prepare_uri actually creates the URI, which you can override.
@@ -228,10 +212,16 @@ sub setup {
 
     unless ($request_class->isa('Catalyst::Request::SmartURI')) {
         my $new_request_class = $app.'::Request::SmartURI';
+
+        my $inject_rest = (not $request_class->isa('Catalyst::Request::REST'))
+            && eval { Class::MOP::load_class('Catalyst::Request::REST') };
+
         Class::C3::Componentised->inject_base(
             $new_request_class,
             'Catalyst::Request::SmartURI',
-            $request_class
+            ($inject_rest ?
+                'Catalyst::Request::REST' : ()),
+            $request_class,
         );
         Class::C3::reinitialize();
 
